MemorySaveContext

Struct MemorySaveContext 

pub struct MemorySaveContext { /* private fields */ }
A save-side SaveContext that keeps every side-car artifact and the committed manifest value in memory.

SaveContext::finish consumes the context and returns an MemoryContext ready to be loaded with the load entry point.

Cleanup on failure

Failures in the same process are automatically cleaned up.

Implementations

Source

impl MemorySaveContext

pub fn new() -> Self

Create an empty in-memory save context.