pub trait Loadable<'a>: Sized {
// Required method
fn load(context: Context<'a>) -> Result<Self>;
}Expand description
Implemented by any value that can be deserialized from a Context.
This is the bottom of the trait hierarchy and is implemented for the same set of
primitive-like types as super::save::Saveable. Most user types should implement
Load (which gets a Loadable impl for free via the blanket below) rather than
Loadable directly.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".